@@ -29,12 +29,6 @@ class PPLoad(GridElement):
         old_state = self.in_service
         self.in_service = True
         self._check(time)
-        if not self.in_service:
-            LOG.debug(
-                f"At step {time}: Load {self.index} with p={self.p_mw:.5f} "
-                f"and q={self.q_mvar:.5f} out of service (Bus voltage: "
-                f"{self.current_bus_voltage:.5f})"
-            )
 
         self.set_value("p_mw", self.p_mw)
         self.set_value("q_mvar", self.q_mvar)
@@ -42,7 +36,24 @@ class PPLoad(GridElement):
 
         # Run powerflow so that the next unit does not automatically
         # switch off, too.
-        if not self.in_service:
-            pp.runpp(self.grid)
+        if old_state != self.in_service:
+            if not self.in_service:
+                LOG.debug(
+                    f"At step {time}: Load {self.index} with p={self.p_mw:.5f} "
+                    f"and q={self.q_mvar:.5f} out of service (Bus voltage: "
+                    f"{self.current_bus_voltage:.5f})"
+                )
+                try:
+                    pp.runpp(self.grid)
+                except pp.LoadflowNotConverged:
+                    LOG.debug("Line disabled. PF still not converging.")
+            else:
+                LOG.debug(
+                    f"At step {time}: Load {self.index} back in service."
+                )
+                try:
+                    pp.runpp(self.grid)
+                except pp.LoadflowNotConverged:
+                    LOG.debug("Load re-enabled. PF not converging.")
 
         return old_state != self.in_service
